package net.sf.doolin.gui.action;

import net.sf.doolin.gui.window.GUIWindow;

/**
 * Closes the current view.
 * 
 * @author Damien Coraboeuf
 * @param <T>
 *            Type of the model for the window
 * 
 */
public class CloseWindowAction<T> extends AbstractSimpleGUIAction {

	@Override
	protected void doExecute(ActionContext context) throws Exception {
		GUIWindow<T> window = context.getWindow();
		if (canClose(window)) {
			close(window);
		}
	}

	/**
	 * Actually closes the window
	 * 
	 * @param window
	 *            Window to close
	 * @see GUIWindow#close()
	 */
	protected void close(GUIWindow<T> window) {
		window.close();
	}

	/**
	 * Checks if the window can be closed by closing all views.
	 * 
	 * 
	 * @param window
	 *            Window to close
	 * @return Result of the check
	 * @see GUIWindow#canClose()
	 */
	protected boolean canClose(GUIWindow<T> window) {
		return window.canClose();
	}

}
