package net.sf.doolin.gui.action;

import javax.swing.Icon;

import net.sf.doolin.gui.display.DisplayStateHandler;
import net.sf.doolin.gui.expression.GUIExpression;
import net.sf.doolin.gui.service.IconSize;

/**
 * Action definition.
 * 
 * @author Damien Coraboeuf
 * 
 */
public interface GUIAction {

	/**
	 * Executes the action.
	 * 
	 * @param actionContext
	 *            Context for the action
	 * @return <code>true</code> if the action has been executed without error
	 */
	boolean execute(ActionContext actionContext);

	/**
	 * Display state handler for this action
	 * 
	 * @return Display state handler
	 */
	DisplayStateHandler getDisplayStateHandler();

	/**
	 * Gets the icon according to its ID
	 * 
	 * @param iconID
	 *            Icon ID
	 * @param iconSize
	 *            Icon size
	 * @return The icon for this action or <code>null</code> if none is
	 *         available.
	 */
	Icon getIcon(String iconID, IconSize iconSize);

	/**
	 * Icon for the action
	 * 
	 * @param actionContext
	 *            Context for the action
	 * @return Icon model
	 */
	GUIExpression getIconIDExpression(ActionContext actionContext);

	/**
	 * ID for the action
	 * 
	 * @return ID
	 */
	String getId();

	/**
	 * Shortcut for the action
	 * 
	 * @param actionContext
	 *            Context for the action
	 * @return Shortcut model
	 */
	GUIExpression getShortcutExpression(ActionContext actionContext);

	/**
	 * Text for the action
	 * 
	 * @param actionContext
	 *            Context for the action
	 * @return Text model
	 */
	GUIExpression getTextExpression(ActionContext actionContext);

	/**
	 * Tip for the action
	 * 
	 * @param actionContext
	 *            Context for the action
	 * @return Tip model
	 */
	GUIExpression getTipExpression(ActionContext actionContext);

}
