/*
 * Created on Jun 6, 2008
 */
package net.sf.doolin.gui.action;

import net.sf.doolin.gui.action.support.DefaultActionContextDataExtractor;
import net.sf.doolin.gui.window.opener.ViewOpener;
import net.sf.doolin.util.factory.DataFactory;

import org.springframework.beans.factory.annotation.Required;

/**
 * Opens a view.
 * 
 * @param <V>
 *            Type of view for the data
 * 
 * @author Damien Coraboeuf
 */
public class OpenViewAction<V> extends AbstractSimpleGUIAction {

	private DataFactory<V> modelFactory;
	private ViewOpener<V> viewOpener;

	/**
	 * Builds a new model and opens the view
	 * 
	 * @see net.sf.doolin.gui.action.AbstractGUIAction#doExecute(net.sf.doolin.gui.action.ActionContext)
	 */
	@Override
	protected void doExecute(ActionContext context) throws Exception {
		// Initial model
		Object data = getActionContextData(context);
		// Creates the view model
		V viewModel = this.modelFactory.create(data);
		// Opens the view
		this.viewOpener.openView(context, viewModel);
	}

	/**
	 * Gets the model factory.
	 * 
	 * @return the model factory
	 */
	public DataFactory<V> getModelFactory() {
		return this.modelFactory;
	}

	/**
	 * Gets the view opener.
	 * 
	 * @return the view opener
	 */
	public ViewOpener<V> getViewOpener() {
		return this.viewOpener;
	}

	/**
	 * Sets the model factory.
	 * 
	 * @param modelFactory
	 *            the model factory
	 */
	@Required
	public void setModelFactory(DataFactory<V> modelFactory) {
		this.modelFactory = modelFactory;
	}

	/**
	 * @param useContextData
	 *            <code>true</code> if the contextual data of the context must
	 *            used instead of the data
	 * @deprecated Use
	 *             {@link AbstractGUIAction#setActionContextDataExtractor(net.sf.doolin.gui.action.support.ActionContextDataExtractor)}
	 */
	@Deprecated
	public void setUseContextData(boolean useContextData) {
		setActionContextDataExtractor(new DefaultActionContextDataExtractor(
				useContextData));
	}

	/**
	 * Sets the view opener.
	 * 
	 * @param viewOpener
	 *            the new view opener
	 */
	@Required
	public void setViewOpener(ViewOpener<V> viewOpener) {
		this.viewOpener = viewOpener;
	}

}
