package net.sf.doolin.gui.action;

import net.sf.doolin.bus.support.TriggeredSubscriberValidator;
import net.sf.doolin.gui.action.support.DefaultActionContextDataExtractor;
import net.sf.doolin.gui.expression.GUIExpression;

import org.springframework.beans.factory.annotation.Required;

/**
 * This action prompts the user for a confirmation and delegates the call to
 * another action. The prompt expression uses the context data for its
 * resolution.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class PromptGUIAction extends AbstractSimpleGUIAction {

	private GUIAction action;
	private String promptExpression;

	@Override
	protected void doExecute(ActionContext context) throws Exception {
		// Gets the message
		TriggeredSubscriberValidator subscriberValidator = new TriggeredSubscriberValidator();
		try {
			Object data = getActionContextData(context);
			String message = new GUIExpression(subscriberValidator, data,
					this.promptExpression).getValue();
			// Asks for confirmation
			if (context.getApplication().getInfoService().confirm(context,
					"PromptGUIAction.prompt", message)) {
				// Delegates to the action
				this.action.execute(context);
			}
		} finally {
			subscriberValidator.stop();
		}
	}

	public GUIAction getAction() {
		return this.action;
	}

	public String getPromptExpression() {
		return this.promptExpression;
	}

	@Required
	public void setAction(GUIAction action) {
		this.action = action;
	}

	@Required
	public void setPromptExpression(String promptExpression) {
		this.promptExpression = promptExpression;
	}

	/**
	 * 
	 * @deprecated Use
	 *             {@link AbstractGUIAction#setActionContextDataExtractor(net.sf.doolin.gui.action.support.ActionContextDataExtractor)}
	 */
	@Deprecated
	public void setUseContextData(boolean useContextData) {
		setActionContextDataExtractor(new DefaultActionContextDataExtractor(
				useContextData));
	}

}
