package net.sf.doolin.gui.action.path.item;

import java.util.List;

import javax.swing.Action;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.action.GUIAction;
import net.sf.doolin.gui.action.swing.ActionFactory;
import net.sf.doolin.gui.action.swing.MenuBuilder;
import net.sf.doolin.gui.service.IconSize;

/**
 * Defines a path to a {@link GUIAction}.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class GUIActionPath extends AbstractActionPath {

	private final GUIAction action;

	/**
	 * Constructor with an action and no path.
	 * 
	 * @param action
	 *            Action to set
	 */
	public GUIActionPath(GUIAction action) {
		super();
		this.action = action;
	}

	/**
	 * Constructor with an action and some paths.
	 * 
	 * @param action
	 *            Action to set
	 * @param paths
	 *            Stack of paths
	 */
	public GUIActionPath(GUIAction action, List<String> paths) {
		super(paths);
		this.action = action;
	}

	/**
	 * Gets the action.
	 * 
	 * @return The action
	 */
	public GUIAction getAction() {
		return this.action;
	}

	/**
	 * @see ActionFactory#createAction(ActionContext, GUIAction, IconSize)
	 * @see MenuBuilder#add(net.sf.doolin.bus.support.SubscriberValidator,
	 *      Action)
	 */
	@Override
	public void install(MenuBuilder menuBuilder, ActionFactory actionFactory,
			ActionContext actionContext) {
		// Creates the Swing action
		Action swingAction = actionFactory.createAction(actionContext,
				this.action, IconSize.SMALL);
		// Adds to the menu builder
		menuBuilder.add(actionContext.getSubscriberValidator(), swingAction);
	}

	@Override
	public String toString() {
		return super.toString() + ">" + this.action.getId();
	}

}
