package net.sf.doolin.gui.action.swing;

import javax.swing.Action;
import javax.swing.JMenu;
import javax.swing.JMenuBar;

import net.sf.doolin.bus.support.SubscriberValidator;

import org.apache.commons.lang.StringUtils;

/**
 * {@link MenuBuilder} for a {@link JMenuBar}.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class JMenuBarBuilder extends AbstractJMenuBuilder {

	private final JMenuBar menuBar;

	/**
	 * Constructor
	 * 
	 * @param menuBar
	 *            Menu bar to build
	 */
	public JMenuBarBuilder(JMenuBar menuBar) {
		this.menuBar = menuBar;
	}

	@Override
	public MenuBuilder createSubMenu(String name, String label) {
		JMenu menu = getMenuByName(name);
		if (menu != null) {
			return (JMenuBuilder) menu.getClientProperty(JMenuBuilder.class);
		} else {
			menu = createMenu(name, label);
			this.menuBar.add(menu);
			noSeparator();
			JMenuBuilder menuContainer = new JMenuBuilder(menu);
			menu.putClientProperty(JMenuBuilder.class, menuContainer);
			return menuContainer;
		}
	}

	/**
	 * Utility method that looks for a sub-menu using the
	 * {@link JMenu#getName() name} of the menu as an identifier.
	 * 
	 * @param name
	 *            Name to find
	 * @return Found {@link JMenu} or <code>null</code>
	 */
	protected JMenu getMenuByName(String name) {
		int count = this.menuBar.getMenuCount();
		for (int i = 0; i < count; i++) {
			JMenu menu = this.menuBar.getMenu(i);
			if (StringUtils.equals(name, menu.getName())) {
				return menu;
			}
		}
		return null;
	}

	@Override
	public void clear() {
		this.menuBar.removeAll();
	}

	@Override
	protected void createSeparator() {
	}

	@Override
	public void add(SubscriberValidator subscriberValidator, Action swingAction) {
	}

}
