package net.sf.doolin.gui.action.swing;

import javax.swing.Action;
import javax.swing.JComponent;

import net.sf.doolin.bus.Bus;
import net.sf.doolin.bus.support.SubscriberValidator;

/**
 * Defines a builder for a menu-like component. It can be menu bars, tool bars,
 * etc.
 * 
 * @author Damien Coraboeuf
 * 
 */
public interface MenuBuilder {

	/**
	 * Creates a sub-menu builder from this builder
	 * 
	 * @param name
	 *            Identifier for the sub-menu
	 * @param label
	 *            Label for the sub-menu
	 * @return Builder for the sub-menu
	 */
	MenuBuilder createSubMenu(String name, String label);

	/**
	 * Adds a separator for this menu
	 */
	void addSeparator();

	/**
	 * Adds a direct component in this menu
	 * 
	 * @param component
	 *            Component to add
	 */
	void add(JComponent component);

	/**
	 * Adds a single action to the builder
	 * 
	 * @param subscriberValidator
	 *            Validator for any subscription on the {@link Bus}	 *
	 * @param swingAction
	 *            Action to add
	 */
	void add(SubscriberValidator subscriberValidator, Action swingAction);

	/**
	 * Removes all entries from the underlying component
	 */
	void clear();

}
