package net.sf.doolin.gui.action.task;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.monitor.TaskException;

/**
 * Defines the executor for a {@link GUITask}.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <B>
 *            Type of bean sent to the task
 * @param <R>
 *            Type of bean returned by the task
 */
public interface GUITaskExecutor<B, R> {

	/**
	 * Executes a given task, starting from a given action context and with a
	 * given bean input.
	 * 
	 * @param actionContext
	 *            Action context to execute the task in
	 * @param bean
	 *            Input for the task
	 * @param task
	 *            Task to execute
	 * @throws TaskException
	 *             If the task has returned an error
	 */
	void execute(ActionContext actionContext, B bean, GUITask<B, R> task)
			throws TaskException;

}
