package net.sf.doolin.gui.action.task;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.util.Utils;

import org.springframework.beans.factory.annotation.Required;

/**
 * Task based on the call of a method.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <B>
 *            Type of bean sent to the task
 * @param <R>
 *            Type of bean returned by the task
 */
public class MethodGUITask<B, R> extends AbstractGUITask<B, R> {

	private String propertyPath = "this";
	private String methodName;

	/**
	 * Gets the property on <code>bean</code> defined by the
	 * <code>propertyPath</code> property and calls the <code>methodName</code>
	 * method on it.
	 */
	@Override
	public R doInBackground(ActionContext actionContext, B bean)
			throws Exception {
		Object target = Utils.getProperty(bean, this.propertyPath);
		@SuppressWarnings("unchecked")
		R result = (R) Utils.callMethod(target, this.methodName);
		return result;
	}

	/**
	 * Does nothing.
	 */
	@Override
	public void doOnResult(ActionContext actionContext, B bean, R result) {
	}

	/**
	 * Sets the method to call on the target property
	 * 
	 * @param methodName
	 *            Method name
	 */
	@Required
	public void setMethodName(String methodName) {
		this.methodName = methodName;
	}

	/**
	 * Sets the path to the property of the input bean of the task. It is set to
	 * "this" by default.
	 * 
	 * @param propertyPath
	 *            Property path
	 */
	public void setPropertyPath(String propertyPath) {
		this.propertyPath = propertyPath;
	}

}
