package net.sf.doolin.gui.display;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.util.Adapter;
import net.sf.doolin.util.Utils;

/**
 * Abstract root for the display state handlers.
 * 
 * @author Damien Coraboeuf
 */
public abstract class AbstractDisplayStateHandler implements
		DisplayStateHandler {

	@Override
	public void connect(final ActionContext actionContext, final Object bean,
			final String propertyPath) {
		connect(actionContext, bean, propertyPath, null);
	}

	@Override
	public <T> void connect(final ActionContext actionContext,
			final Object bean, final String propertyPath,
			final Adapter<DisplayState, T> adapter) {
		Runnable task = new Runnable() {

			@Override
			public void run() {
				DisplayState state = getDisplayState(actionContext);
				Object value;
				if (adapter != null) {
					value = adapter.convertSubjectToTarget(state);
				} else {
					value = state;
				}
				Utils.setProperty(bean, propertyPath, value);
			}
		};
		subscribe(actionContext, task);
		task.run();
	}

}
