package net.sf.doolin.gui.display;

/**
 * Adapter from a {@link Boolean} value to a {@link DisplayState}.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class BooleanStateAdapter extends AbstractStateAdapter<Boolean> {

	private DisplayState ifTrueState = DisplayState.ENABLED;
	private DisplayState ifFalseState = DisplayState.DISABLED;

	@Override
	public DisplayState convertSubjectToTarget(Boolean subjectValue) {
		if (subjectValue != null && subjectValue) {
			return ifTrueState;
		} else {
			return ifFalseState;
		}
	}

	/**
	 * Gets the state if the boolean is evaluated to <code>true</code>
	 * 
	 * @return State
	 */
	public DisplayState getIfTrueState() {
		return ifTrueState;
	}

	/**
	 * Sets the state to return if the boolean is evaluated to <code>true</code>
	 * 
	 * @param ifTrueState
	 *            State
	 */
	public void setIfTrueState(DisplayState ifTrueState) {
		this.ifTrueState = ifTrueState;
	}

	/**
	 * Gets the state if the boolean is evaluated to <code>false</code>
	 * 
	 * @return State
	 */
	public DisplayState getIfFalseState() {
		return ifFalseState;
	}

	/**
	 * Sets the state to return if the boolean is evaluated to
	 * <code>false</code>
	 * 
	 * @param ifFalseState
	 *            State
	 */
	public void setIfFalseState(DisplayState ifFalseState) {
		this.ifFalseState = ifFalseState;
	}

}
