package net.sf.doolin.gui.display;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.util.Adapter;

/**
 * Defines the display state of a field.
 * 
 * @author Damien Coraboeuf
 * 
 */
public interface DisplayStateHandler {

	/**
	 * Connects this {@link DisplayStateHandler} to the given property and for
	 * the given {@link ActionContext}. Each time this display state handler
	 * changes its state, this new state will be set in the given property of
	 * the given bean.
	 * 
	 * @param actionContext
	 *            Action context
	 * @param bean
	 *            Target bean
	 * @param propertyPath
	 *            Path to the property in the target bean that will contain the
	 *            new state
	 */
	void connect(ActionContext actionContext, Object bean, String propertyPath);

	/**
	 * Connects this {@link DisplayStateHandler} to the given property and for
	 * the given {@link ActionContext}. Each time this display state handler
	 * changes its state, this new state will be converted to another type and
	 * will be set in the given property of the given bean.
	 * 
	 * @param actionContext
	 *            Action context
	 * @param bean
	 *            Target bean
	 * @param propertyPath
	 *            Path to the property in the target bean that will contain the
	 *            converted new state
	 * @param adapter
	 *            Adapter to convert the new state to the type of the target
	 *            property
	 * 
	 * @param <T>
	 *            Type of the target property
	 */
	<T> void connect(ActionContext actionContext, Object bean,
			String propertyPath, Adapter<DisplayState, T> adapter);

	/**
	 * Subscribes a task that is executed each time this display state handler
	 * changes its state.
	 * 
	 * @param actionContext
	 *            Action context for this display state handler
	 * @param task
	 *            Task to run each time the state change
	 */
	void subscribe(ActionContext actionContext, Runnable task);

	/**
	 * Gets the current {@link DisplayState} for the given action context
	 * 
	 * @param actionContext
	 *            Action context.
	 * @return Display state
	 */
	DisplayState getDisplayState(ActionContext actionContext);

}
