package net.sf.doolin.gui.display;

import net.sf.doolin.gui.action.ActionContext;

/**
 * Inverts the display state given by another display state handler.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class NotDisplayStateHandler extends AbstractDisplayStateHandler {

	private final DisplayStateHandler handler;
	private final DisplayState notEnabledState;

	/**
	 * Constructor.
	 * 
	 * @param handler
	 *            Handler to negate
	 */
	public NotDisplayStateHandler(DisplayStateHandler handler) {
		this(handler, DisplayState.DISABLED);
	}

	/**
	 * Constructor.
	 * 
	 * @param handler
	 *            Handler to negate
	 * @param notEnabledState
	 *            State when not enabled
	 */
	public NotDisplayStateHandler(DisplayStateHandler handler,
			DisplayState notEnabledState) {
		this.handler = handler;
		this.notEnabledState = notEnabledState;
	}

	@Override
	public DisplayState getDisplayState(ActionContext actionContext) {
		DisplayState state = this.handler.getDisplayState(actionContext);
		switch (state) {
		case ENABLED:
		default:
			return NotDisplayStateHandler.this.notEnabledState;
		case DISABLED:
		case HIDDEN:
			return DisplayState.ENABLED;
		}
	}

	@Override
	public void subscribe(ActionContext actionContext, Runnable task) {
		this.handler.subscribe(actionContext, task);
	}

}
