package net.sf.doolin.gui.edit;

/**
 * Manager for a list of tasks that can be done and undone.
 * 
 * @author Damien Coraboeuf
 * 
 */
public interface GUIEditManager {

	/**
	 * Adds a new task.
	 * 
	 * @param record
	 *            Task to record
	 */
	void addEdit(GUIEdit record);

	/**
	 * Checks if some tasks are available for undoing.
	 * 
	 * @return <code>true</code> if some tasks are available for undoing.
	 */
	boolean canUndo();

	/**
	 * Checks if some tasks are available for doing again.
	 * 
	 * @return <code>true</code> if some tasks are available for doing again.
	 */
	boolean canRedo();

	/**
	 * Undoes the next available task (if possible).
	 */
	void undo();

	/**
	 * Redoes the next available task (if possible).
	 */
	void redo();

	/**
	 * Gets the display name for the action that can be redone.
	 * 
	 * @return Display name
	 */
	String getRedoDisplayName();

	/**
	 * Gets the display name for the action that can be undone.
	 * 
	 * @return Display name
	 */
	String getUndoDisplayName();

	/**
	 * Clears all tasks
	 */
	void clear();

}
