package net.sf.doolin.gui.field;

import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Font;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

import javax.swing.BorderFactory;
import javax.swing.JLabel;
import javax.swing.JPanel;

import net.sf.doolin.gui.swing.JFontChooser;
import net.sf.doolin.gui.expression.GUIExpression;
import net.sf.doolin.gui.field.support.SimpleField;
import net.sf.doolin.gui.view.GUIView;

/**
 * This field allows the user to pick a {@link Font}.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <V>
 *            Type of bean for the view
 */
public class FieldFont<V> extends AbstractPropertyFieldDescriptor<V> {

	private static final long serialVersionUID = 1L;

	private String sampleString = "aAbBcCdDeE";

	@Override
	public Field<V> createField(final GUIView<V> view) {
		final GUIExpression expression = new GUIExpression(view
				.getActionContext().getSubscriberValidator(), view
				.getViewData(), FieldFont.this.sampleString);
		JPanel panel = new JPanel(new FlowLayout());
		final JLabel label = new JLabel();
		expression.connect(view.getActionContext().getSubscriberValidator(),
				label, "text");
		panel.add(label);
		panel.setPreferredSize(new Dimension(100, 32));
		panel.setBorder(BorderFactory.createEtchedBorder());
		// Event handling
		panel.addMouseListener(new MouseAdapter() {

			@Override
			public void mouseClicked(MouseEvent e) {
				if (e.getButton() == MouseEvent.BUTTON1) {
					Font font = label.getFont();
					JFontChooser chooser = new JFontChooser();
					chooser.setSelectedFont(font);
					chooser.setSampleString(expression.getValue());
					int result = chooser.showDialog(label);
					if (result == JFontChooser.OK_OPTION) {
						font = chooser.getSelectedFont();
						if (font != null) {
							label.setFont(font);
							setProperty(view, font);
						}
					}
				}
			}

		});
		// Model -> Panel
		subscribe(view, label, "font");
		// OK
		return new SimpleField<V>(view, this, panel);
	}

	/**
	 * Gets the text which is used as a sample text to display the font.
	 * 
	 * @return Sample string
	 */
	public String getSampleString() {
		return this.sampleString;
	}

	/**
	 * Sets the text which is used as a sample text to display the font. It is
	 * set by default to "aAbBcCdDeE".
	 * 
	 * @param sampleString
	 *            Sample string
	 */
	public void setSampleString(String sampleString) {
		this.sampleString = sampleString;
	}

}
