package net.sf.doolin.gui.field;

import javax.swing.JComponent;
import javax.swing.SwingConstants;

import net.sf.doolin.gui.expression.GUIExpression;
import net.sf.doolin.gui.field.support.SimpleField;
import net.sf.doolin.gui.view.GUIView;
import net.sf.doolin.util.Utils;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.jgoodies.forms.factories.ComponentFactory;
import com.jgoodies.forms.factories.DefaultComponentFactory;

/**
 * Descriptor for a separator.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <V>
 *            Type of data for the view
 */
public class FieldSeparator<V> extends AbstractFieldDescriptor<V> {

	private static final long serialVersionUID = 1L;

	private static final Logger log = LoggerFactory.getLogger(FieldSeparator.class);

	private String titleExpression;
	private String alignment = "LEFT";
	private ComponentFactory componentFactory = DefaultComponentFactory
			.getInstance();

	@Override
	public Field<V> createField(GUIView<V> view) {
		// Alignment constant
		int alignmentConstant = (Integer) Utils.getConstant(
				SwingConstants.class, this.alignment);
		// Title expression
		final GUIExpression expression = new GUIExpression(view
				.getActionContext().getSubscriberValidator(), view
				.getViewData(), this.titleExpression);
		// Separator
		JComponent separator = this.componentFactory.createSeparator(expression
				.getValue(), alignmentConstant);
		// Title changes cannot be tkane into account
		// because the title of the separator is not accessible
		if (expression.isVariable()) {
			log.warn("Separators cannot manage variable titles");
		}
		// OK
		return new SimpleField<V>(view, this, separator);
	}

	/**
	 * Gets the alignment.
	 * 
	 * @return the alignment
	 */
	public String getAlignment() {
		return this.alignment;
	}

	/**
	 * Gets the component factory.
	 * 
	 * @return the component factory
	 */
	public ComponentFactory getComponentFactory() {
		return this.componentFactory;
	}

	/**
	 * Gets the title expression.
	 * 
	 * @return the title expression
	 */
	public String getTitleExpression() {
		return this.titleExpression;
	}

	/**
	 * Alignment of the title in the separator
	 * 
	 * @param alignment
	 *            the new alignment
	 */
	public void setAlignment(String alignment) {
		this.alignment = alignment;
	}

	/**
	 * Factory for the components
	 * 
	 * @param componentFactory
	 *            the new component factory
	 */
	public void setComponentFactory(ComponentFactory componentFactory) {
		this.componentFactory = componentFactory;
	}

	/**
	 * Expression for the title
	 * 
	 * @param titleExpression
	 *            the new title expression
	 */
	public void setTitleExpression(String titleExpression) {
		this.titleExpression = titleExpression;
	}

}
