package net.sf.doolin.gui.field.support;

import javax.swing.JComponent;

import net.sf.doolin.bus.support.SubscriberValidator;
import net.sf.doolin.gui.app.GUIApplication;
import net.sf.doolin.gui.field.Field;
import net.sf.doolin.gui.view.GUIView;
import net.sf.doolin.gui.view.support.ViewSubscriberValidator;
import net.sf.doolin.gui.window.GUIWindow;

/**
 * Action context for a field.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <V>
 *            Type of object for the view
 */
public class FieldActionContext<V> extends AbstractFieldActionContext {

	private static final long serialVersionUID = 1L;

	private final Field<V> field;
	private SubscriberValidator subscriberValidator;

	/**
	 * Constructor
	 * 
	 * @param field
	 *            Field
	 */
	public FieldActionContext(Field<V> field) {
		super(field.getView().getViewData());
		this.field = field;
		GUIView<V> view = getView();
		this.subscriberValidator = new ViewSubscriberValidator<V>(view);
	}

	/**
	 * Constructor with an initial context value
	 * 
	 * @param field
	 *            Field
	 * @param context
	 *            Initial context value
	 */
	public FieldActionContext(Field<V> field, Object context) {
		super(context);
		this.field = field;
		GUIView<V> view = getView();
		this.subscriberValidator = new ViewSubscriberValidator<V>(view);
	}

	@Override
	public GUIApplication getApplication() {
		return getWindow().getApplication();
	}

	@Override
	public JComponent getComponent() {
		return this.field.getFieldComponent();
	}

	@Override
	public Object getData() {
		return this.field.getView().getViewData();
	}

	@Override
	public SubscriberValidator getSubscriberValidator() {
		return this.subscriberValidator;
	}

	@SuppressWarnings("unchecked")
	@Override
	public <T> GUIView<T> getView() {
		return (GUIView<T>) this.field.getView();
	}

	@SuppressWarnings("unchecked")
	@Override
	public <T> GUIWindow<T> getWindow() {
		return (GUIWindow<T>) this.field.getView().getParentWindow();
	}

}
