package net.sf.doolin.gui.field.table.action;

import java.util.Collection;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.action.DialogAction;
import net.sf.doolin.util.Utils;

/**
 * This action displays a dialog to create an item and then adds this item to
 * the collection defined by the property path.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <E>
 *            Type of object to edit
 */
public class NewItemAction<E> extends DialogAction<E> {

	private String propertyPath;

	@Override
	protected void onOK(ActionContext actionContext, E bean) {
		@SuppressWarnings("unchecked")
		Collection<E> collection = (Collection<E>) Utils.getProperty(
				actionContext.getData(), this.propertyPath);
		collection.add(bean);
	}

	/**
	 * Gets the property path to the collection to add the new item to
	 * 
	 * @return Property path
	 */
	public String getPropertyPath() {
		return this.propertyPath;
	}

	/**
	 * Sets the property path to the collection to add the new item to
	 * 
	 * @param propertyPath
	 *            Property path
	 */
	public void setPropertyPath(String propertyPath) {
		this.propertyPath = propertyPath;
	}

}
