package net.sf.doolin.gui.field.table.header.support;

import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

import javax.swing.JPopupMenu;
import javax.swing.table.JTableHeader;

import net.sf.doolin.gui.field.table.FieldTable;
import net.sf.doolin.gui.field.table.header.GUITableHeaderFactory;
import net.sf.doolin.gui.field.table.header.GUITableHeaderMenuFactory;
import net.sf.doolin.gui.field.table.support.GUITable;
import net.sf.doolin.gui.field.table.support.GUITableField;

/**
 * Default actory for the header of a {@link GUITable}.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <V>
 *            Type of object for the view
 * @param <E>
 *            Type of item in the table
 */
public class DefaultGUITableHeaderFactory<V, E> implements
		GUITableHeaderFactory<V, E> {

	private GUITableHeaderMenuFactory<V, E> headerMenuFactory = new DefaultGUITableHeaderMenuFactory<V, E>();

	@Override
	public JTableHeader createHeader(final GUITable<V, E> table) {
		// Table descriptor
		GUITableField<V, E> tableField = table.getTableField();
		FieldTable<V, E> tableDescriptor = tableField.getTableDescriptor();
		// No columns?
		if (!tableDescriptor.isShowColumns()) {
			return null;
		}
		// Creates the header
		else {
			// Gets the default header
			final JTableHeader header = table.getTableHeader();
			// Right-click on the header for the selection of columns
			header.addMouseListener(new MouseAdapter() {
				@Override
				public void mouseReleased(MouseEvent e) {
					if (e.isPopupTrigger()) {
						JPopupMenu menu = DefaultGUITableHeaderFactory.this.headerMenuFactory
								.createMenu(table);
						// Displays the menu
						if (menu != null) {
							menu.show(header, e.getX(), e.getY());
						}
					}
				}
			});
			// OK
			return header;
		}
	}

	/**
	 * @return the headerMenuFactory
	 */
	public GUITableHeaderMenuFactory<V, E> getHeaderMenuFactory() {
		return this.headerMenuFactory;
	}

	/**
	 * @param headerMenuFactory
	 *            the headerMenuFactory to set
	 */
	public void setHeaderMenuFactory(
			GUITableHeaderMenuFactory<V, E> headerMenuFactory) {
		this.headerMenuFactory = headerMenuFactory;
	}

}
