package net.sf.doolin.gui.field.table.renderer;

import java.awt.Component;

import javax.swing.JTable;
import javax.swing.table.TableCellRenderer;

import net.sf.doolin.gui.field.table.style.TableStyle;
import net.sf.doolin.gui.field.table.support.GUITable;
import net.sf.doolin.gui.style.Style;

/**
 * This table renderer is used as an ancestor for all renderers that want to
 * interact with a style defined at table level.
 * 
 * @author Damien Coraboeuf
 * @param <E>
 *            Type of item in the table
 */
public class GUITableCellRenderer<E> implements TableCellRenderer {

	private final TableCellRenderer support;

	/**
	 * Instantiates a new gUI table cell renderer.
	 * 
	 * @param renderer
	 *            the renderer
	 */
	public GUITableCellRenderer(TableCellRenderer renderer) {
		this.support = renderer;
	}

	/**
	 * Applies style.
	 * 
	 * @param component
	 *            the component
	 * @param table
	 *            the table
	 * @param row
	 *            the row
	 * @param column
	 *            the column
	 */
	protected void applyStyle(Component component, JTable table, int row,
			int column) {
		// GUI table ?
		if (table instanceof GUITable<?, ?>) {
			// GUI table
			@SuppressWarnings("unchecked")
			GUITable<?, E> guiTable = (GUITable<?, E>) table;
			// Default style
			component.setBackground(table.getBackground());
			// Style
			TableStyle style = guiTable.getTableStyle();
			if (style != null) {
				// Gets the object from the model
				E item = guiTable.getEventTableModel().getElementAt(row);
				// Applies the style
				Style rowStyle = style.getStyle(item, table, row, column);
				if (rowStyle != null) {
					rowStyle.apply(component);
				}
			}
		}
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public Component getTableCellRendererComponent(JTable table, Object value,
			boolean isSelected, boolean hasFocus, int row, int column) {
		// Default
		Component component = this.support.getTableCellRendererComponent(table,
				value, isSelected, hasFocus, row, column);
		// Style application
		if (!isSelected) {
			applyStyle(component, table, row, column);
		}
		// OK
		return component;
	}

}
