package net.sf.doolin.gui.field.table.style;

import java.awt.Color;

import javax.swing.JTable;

import net.sf.doolin.gui.style.BackgroundStyle;
import net.sf.doolin.gui.style.Style;

/**
 * Style that alternates colors between rows.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class AlternateColorTableStyle implements TableStyle {

	private Color evenRowColor = Color.WHITE;

	private Color oddRowColor = Color.LIGHT_GRAY;

	/**
	 * {@inheritDoc}
	 */
	@Override
	public Style getStyle(Object item, JTable table, int row, int column) {
		if (row % 2 == 0) {
			return new BackgroundStyle(getEvenRowColor());
		} else {
			return new BackgroundStyle(getOddRowColor());
		}
	}

	/**
	 * Gets the even row color.
	 * 
	 * @return the even row color
	 */
	public Color getEvenRowColor() {
		return this.evenRowColor;
	}

	/**
	 * Sets the even row color.
	 * 
	 * @param evenRowColor
	 *            the new even row color
	 */
	public void setEvenRowColor(Color evenRowColor) {
		this.evenRowColor = evenRowColor;
	}

	/**
	 * Gets the odd row color.
	 * 
	 * @return the odd row color
	 */
	public Color getOddRowColor() {
		return this.oddRowColor;
	}

	/**
	 * Sets the odd row color.
	 * 
	 * @param oddRowColor
	 *            the new odd row color
	 */
	public void setOddRowColor(Color oddRowColor) {
		this.oddRowColor = oddRowColor;
	}

}
