package net.sf.doolin.gui.field.table.style;

import java.util.HashMap;
import java.util.Map;

import javax.swing.JTable;

import net.sf.doolin.gui.style.Style;
import net.sf.doolin.util.Utils;

import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Required;

/**
 * Style that applies another style according to the value of a property of the
 * row item.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class PropertyValueTableStyle implements TableStyle {

	private String propertyPath;

	private Map<String, TableStyle> styleMap = new HashMap<String, TableStyle>();

	private TableStyle defaultStyle = new DefaultTableStyle();

	@Override
	public Style getStyle(Object item, JTable table, int row, int column) {
		if (this.styleMap != null && this.propertyPath != null) {
			// Gets the property value
			Object propertyValue = Utils.getProperty(item, this.propertyPath);
			// As a string
			String propertyKey = ObjectUtils.toString(propertyValue, "");
			// Gets the style
			TableStyle style = this.styleMap.get(propertyKey);
			if (style != null) {
				// Applies the style
				return style.getStyle(item, table, row, column);
			}
			// Default style
			else {
				return this.defaultStyle.getStyle(item, table, row, column);
			}
		} else {
			return null;
		}
	}

	/**
	 * Gets the style map.
	 * 
	 * @return the style map
	 */
	public Map<String, TableStyle> getStyleMap() {
		return this.styleMap;
	}

	/**
	 * Sets the styles indexed by property value.
	 * 
	 * @param styleMap
	 *            the style map
	 */
	@Required
	public void setStyleMap(Map<String, TableStyle> styleMap) {
		this.styleMap = styleMap;
	}

	/**
	 * Gets the property path.
	 * 
	 * @return the property path
	 */
	public String getPropertyPath() {
		return this.propertyPath;
	}

	/**
	 * Sets the property path.
	 * 
	 * @param propertyPath
	 *            the new property path
	 */
	@Required
	public void setPropertyPath(String propertyPath) {
		this.propertyPath = propertyPath;
	}

	/**
	 * Gets the default style.
	 * 
	 * @return the default style
	 */
	public TableStyle getDefaultStyle() {
		return this.defaultStyle;
	}

	/**
	 * Sets the default style to apply if the property value is not found in the
	 * map.
	 * 
	 * @param defaultStyle
	 *            the new default style
	 */
	public void setDefaultStyle(TableStyle defaultStyle) {
		this.defaultStyle = defaultStyle;
	}

}
