package net.sf.doolin.gui.field.table.support;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JCheckBoxMenuItem;

import net.sf.doolin.gui.expression.GUIExpression;
import net.sf.doolin.gui.field.table.Column;

/**
 * Check-box menu item for the menu that allows the user to define the
 * visibility of columns.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <V>
 *            Type of bean for the view
 * @param <E>
 *            Type of bean for the row
 */
public class ColumnMenuItem<V, E> extends JCheckBoxMenuItem {

	private static final long serialVersionUID = 1L;

	/**
	 * Constructor.
	 * 
	 * @param column
	 *            Column to make visible/invisible
	 * @param table
	 *            Table container
	 */
	public ColumnMenuItem(final Column column, final GUITable<V, E> table) {
		setText(new GUIExpression(null, null, column.getTitleExpression())
				.getValue());
		setEnabled(!column.isRequired());
		setSelected(column.isVisible());
		addActionListener(new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent e) {
				if (!column.isRequired()) {
					boolean visible = column.isVisible();
					visible = !visible;
					column.setVisible(visible);
					table.reinit();
				}
			}
		});
	}

}
