package net.sf.doolin.gui.layout;

import java.awt.BorderLayout;
import java.awt.LayoutManager;

import javax.swing.JComponent;
import javax.swing.JPanel;

/**
 * Layout service based on a {@link java.awt.LayoutManager}.
 * 
 * @author Damien Coraboeuf
 */
public class LayoutManagerService implements LayoutService {

	private LayoutManager layoutManager = new BorderLayout(4, 4);

	private LayoutConstraintAdapter<Object, Object> constraintAdapter = new IdentityLayoutConstraintAdapter<Object>();

	/**
	 * Gets the layout manager.
	 * 
	 * @return the layout manager
	 */
	public LayoutManager getLayoutManager() {
		return layoutManager;
	}

	/**
	 * Sets the layout manager.
	 * 
	 * @param layoutManager
	 *            the new layout manager
	 */
	public void setLayoutManager(LayoutManager layoutManager) {
		this.layoutManager = layoutManager;
	}

	/**
	 * Gets the constraint adapter.
	 * 
	 * @return the constraint adapter
	 */
	public LayoutConstraintAdapter<Object, Object> getConstraintAdapter() {
		return constraintAdapter;
	}

	/**
	 * Sets the constraint adapter.
	 * 
	 * @param constraintAdapter
	 *            the constraint adapter
	 */
	public void setConstraintAdapter(
			LayoutConstraintAdapter<Object, Object> constraintAdapter) {
		this.constraintAdapter = constraintAdapter;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public void add(JPanel panel, JComponent component, Object constraint) {
		// Adapts the constraint
		Object adaptedConstraint = constraintAdapter.convert(constraint);
		// Adds the component
		panel.add(component, adaptedConstraint);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public void init(JPanel panel) {
		panel.setLayout(layoutManager);
	}

}
