package net.sf.doolin.gui.lf;

import java.awt.Window;

import javax.swing.JPanel;
import javax.swing.LookAndFeel;
import javax.swing.SwingUtilities;
import javax.swing.UIManager;
import javax.swing.UIManager.LookAndFeelInfo;

import net.sf.doolin.bus.Bus;
import net.sf.doolin.gui.action.AbstractGUIAction;
import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.expression.GUIExpression;
import net.sf.doolin.util.Utils;

/**
 * Action that applies a look and feel for the current window
 * 
 * @author Damien Coraboeuf
 * 
 */
public class LFAction extends AbstractGUIAction {

	private LookAndFeelInfo lookAndFeelInfo;

	@Override
	public GUIExpression getIconIDExpression(ActionContext actionContext) {
		return null;
	}

	@Override
	public String getId() {
		return this.lookAndFeelInfo.toString();
	}

	/**
	 * Gets the look and feel info.
	 * 
	 * @return the look and feel info
	 */
	public LookAndFeelInfo getLookAndFeelInfo() {
		return this.lookAndFeelInfo;
	}

	@Override
	public GUIExpression getShortcutExpression(ActionContext actionContext) {
		return null;
	}

	@Override
	public GUIExpression getTextExpression(ActionContext actionContext) {
		return new GUIExpression(actionContext.getSubscriberValidator(),
				actionContext.getData(), this.lookAndFeelInfo.getName());
	}

	@Override
	public GUIExpression getTipExpression(ActionContext actionContext) {
		return null;
	}

	/**
	 * Sets the look and feel info.
	 * 
	 * @param lookAndFeelInfo
	 *            the new look and feel info
	 */
	public void setLookAndFeelInfo(LookAndFeelInfo lookAndFeelInfo) {
		this.lookAndFeelInfo = lookAndFeelInfo;
	}

	@Override
	protected void doExecute(ActionContext context) throws Exception {
		UIManager.installLookAndFeel(this.lookAndFeelInfo);
		UIManager.setLookAndFeel((LookAndFeel) Utils
				.newInstance(this.lookAndFeelInfo.getClassName()));
		JPanel windowComponent = context.getWindow().getWindowPanel();
		Window window = SwingUtilities.getWindowAncestor(windowComponent);
		SwingUtilities.updateComponentTreeUI(window);
		// Notifies the change
		Bus.get().publish(new LFChanged(this.lookAndFeelInfo));
	}

}
