package net.sf.doolin.gui.monitor;

import java.util.concurrent.Callable;

/**
 * {@link Task} based on a {@link Callable}.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <T>
 *            Return type for the {@link Callable}
 */
public class CallableTask<T> extends Task<T, Void> {

	private final Callable<T> callable;

	/**
	 * Constructor
	 * 
	 * @param callable
	 *            {@link Callable} to call
	 */
	public CallableTask(Callable<T> callable) {
		this.callable = callable;
	}

	/**
	 * Calls the {@link Callable}
	 * 
	 * @see Callable#call()
	 */
	@Override
	protected T doInBackground() throws Exception {
		return callable.call();
	}

}
