package net.sf.doolin.gui.spring;

import net.sf.doolin.context.spring.SimpleBeanFactory;
import net.sf.doolin.gui.model.EnumListDataFactory;
import net.sf.doolin.gui.model.PropertyDataFactory;
import net.sf.doolin.gui.swing.EnumLabelInfoProvider;
import net.sf.doolin.util.Utils;

import org.springframework.beans.factory.support.BeanDefinitionBuilder;

/**
 * Parser for an
 * {@link net.sf.doolin.gui.field.list.AbstractListPropertyFieldDescriptor}
 * 
 * @author Damien Coraboeuf
 * 
 * @param <C>
 *            Type of the bean to parse
 */
public class AbstractListPropertyFieldTypeParser<C> extends
		AbstractPropertyFieldTypeParser<C> {

	/**
	 * Constructor
	 * 
	 * @param beanClass
	 *            Bean class
	 */
	public AbstractListPropertyFieldTypeParser(Class<C> beanClass) {
		super(beanClass);
		addSimpleAttribute("itemListAddNull");
		// enumListFactory => EnumListDataFactory
		addFactoryFromAttribute("enumListFactory", "itemListFactory",
				new SimpleBeanFactory() {

					@Override
					@SuppressWarnings("unchecked")
					public Object create(String value) {
						Class enumClass = Utils.forClass(value);
						return createEnumListDataFactory(enumClass);
					}

					private <E extends Enum<E>> EnumListDataFactory<E> createEnumListDataFactory(
							Class<E> enumClass) {
						EnumListDataFactory<E> f = new EnumListDataFactory<E>(
								enumClass);
						return f;
					}

				});
		// enumListFactory => EnumLabelInfoProvider
		addFactoryFromAttribute("enumListFactory", "labelInfoProvider",
				new SimpleBeanFactory() {

					@Override
					public Object create(String value) {
						BeanDefinitionBuilder builder = BeanDefinitionBuilder
								.rootBeanDefinition(EnumLabelInfoProvider.class);
						return builder.getBeanDefinition();
					}

				});
		// itemListPropertyPath ==> PropertyDataFactory
		addFactoryFromAttribute("itemListPropertyPath", "itemListFactory",
				new SimpleBeanFactory() {

					@Override
					public Object create(String value) {
						BeanDefinitionBuilder builder = BeanDefinitionBuilder
								.rootBeanDefinition(PropertyDataFactory.class);
						builder.addPropertyValue("propertyPath", value);
						return builder.getBeanDefinition();
					}
				});
	}
}
