package net.sf.doolin.gui.spring;

import java.awt.LayoutManager;
import java.util.ArrayList;
import java.util.List;

import net.sf.doolin.context.spring.AbstractDefinitionParser;
import net.sf.doolin.gui.layout.LayoutManagerService;
import net.sf.doolin.util.Pair;
import net.sf.doolin.util.Utils;
import net.sf.doolin.util.xml.DOMUtils;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.config.BeanDefinition;
import org.springframework.beans.factory.support.BeanDefinitionBuilder;
import org.springframework.beans.factory.xml.ParserContext;
import org.w3c.dom.Element;

public class LayoutManagerServiceParser<L extends LayoutManager> extends
		AbstractDefinitionParser {

	private final Class<L> layoutManagerClass;

	private final List<String> attributes = new ArrayList<String>();
	private final List<Pair<Class<?>, String>> constantAttributes = new ArrayList<Pair<Class<?>, String>>();

	public LayoutManagerServiceParser(Class<L> layoutManagerClass) {
		this.layoutManagerClass = layoutManagerClass;
	}

	public LayoutManagerServiceParser<L> addAttribute(String attribute) {
		this.attributes.add(attribute);
		return this;
	}

	public LayoutManagerServiceParser<L> addConstantAttribute(
			Class<?> container, String attribute) {
		this.constantAttributes.add(new Pair<Class<?>, String>(container,
				attribute));
		return this;
	}

	@Override
	public void doParse(Element element, ParserContext parserContext,
			BeanDefinitionBuilder builder) {
		BeanDefinitionBuilder layoutBuilder = BeanDefinitionBuilder
				.rootBeanDefinition(this.layoutManagerClass);
		// Additional attributes
		for (String attribute : this.attributes) {
			setAttributeAsProperty(element, attribute, layoutBuilder);
		}
		// Swing constant attributes
		for (Pair<Class<?>, String> pair : this.constantAttributes) {
			Class<?> container = pair.getFirstValue();
			String attribute = pair.getSecondValue();
			// Gets the attribute
			String attValue = DOMUtils.getAttribute(element, attribute, false,
					null);
			if (StringUtils.isNotBlank(attValue)) {
				// Converts
				Object value = Utils.getConstant(container, attValue);
				// OK
				layoutBuilder.addPropertyValue(attribute, value);
			}
		}

		// OK
		builder.addPropertyValue("layoutManager", layoutBuilder
				.getBeanDefinition());

		// Container
		BeanDefinition containingBeanDefinition = parserContext
				.getContainingBeanDefinition();
		if (containingBeanDefinition != null) {
			containingBeanDefinition.getPropertyValues().addPropertyValue(
					"layout", builder.getBeanDefinition());
		}
	}

	@Override
	protected Class<LayoutManagerService> getBeanClass(Element element) {
		return LayoutManagerService.class;
	}

}
