package net.sf.doolin.gui.spring;

import java.util.List;
import java.util.Properties;

import net.sf.doolin.context.spring.AbstractDefinitionParser;
import net.sf.doolin.util.xml.DOMUtils;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.config.BeanDefinition;
import org.springframework.beans.factory.config.BeanDefinitionHolder;
import org.springframework.beans.factory.support.BeanDefinitionBuilder;
import org.springframework.beans.factory.support.GenericBeanDefinition;
import org.springframework.beans.factory.xml.BeanDefinitionDecorator;
import org.springframework.beans.factory.xml.ParserContext;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

/**
 * Parser and decorator for a set of properties
 * 
 * @author Damien Coraboeuf
 * 
 */
public class PropertiesDecorator extends AbstractDefinitionParser implements
		BeanDefinitionDecorator {

	private static final Logger log = LoggerFactory.getLogger(PropertiesDecorator.class);

	@Override
	protected Class<Properties> getBeanClass(Element element) {
		return Properties.class;
	}

	@Override
	public void doParse(Element eProperties, ParserContext context,
			BeanDefinitionBuilder builder) {
		Object value = getProperties(eProperties, context, builder
				.getBeanDefinition());
		if (value != null) {
			builder.addPropertyValue("properties", value);
		}
		// OK
		super.doParse(eProperties, context, builder);
	}

	private Object getProperties(Element eProperties, ParserContext context,
			BeanDefinition definition) {
		Object value;
		List<Element> childElements = DOMUtils.getElements(eProperties);
		if (!childElements.isEmpty()) {
			Element eChild = childElements.get(0);
			String ns = eChild.getNamespaceURI();
			String childName = eChild.getLocalName();
			if ("http://www.springframework.org/schema/util".equals(ns)
					&& "properties".equals(childName)) {
				value = context.getDelegate().parseCustomElement(eChild,
						definition);
			} else if ("http://www.springframework.org/schema/beans".equals(ns)
					&& "props".equals(childName)) {
				value = context.getDelegate().parsePropsElement(eChild);
			} else {
				log.error(String.format("Cannot parse properties for %s#%s",
						ns, childName));
				value = null;
			}
		} else {
			value = null;
		}
		return value;
	}

	@Override
	public BeanDefinitionHolder decorate(Node node,
			BeanDefinitionHolder holder, ParserContext context) {
		Element eProperties = (Element) node;
		Object value = getProperties(eProperties, context, holder
				.getBeanDefinition());
		if (value != null) {
			GenericBeanDefinition definition = new GenericBeanDefinition(holder
					.getBeanDefinition());
			definition.getPropertyValues()
					.addPropertyValue("properties", value);
			return new BeanDefinitionHolder(definition, holder.getBeanName());
		} else {
			return holder;
		}
	}
}
