package net.sf.doolin.gui.spring.table;

import net.sf.doolin.context.spring.SimpleDefinitionParser;
import net.sf.doolin.gui.field.table.renderer.LabelInfoTableCellRenderer;
import net.sf.doolin.gui.swing.ExpressionLabelInfoProvider;

import org.springframework.beans.factory.support.BeanDefinitionBuilder;
import org.springframework.beans.factory.xml.ParserContext;
import org.w3c.dom.Element;

/**
 * * Decorator for a {@link LabelInfoTableCellRenderer} based on
 * {@link net.sf.doolin.gui.swing.ExpressionLabelInfoProvider}.
 * 
 * @author Damien Coraboeuf
 */
public class ColumnExpressionDecorator extends
		SimpleDefinitionParser<LabelInfoTableCellRenderer> {

	/**
	 * Instantiates a new column expression decorator.
	 */
	public ColumnExpressionDecorator() {
		super(LabelInfoTableCellRenderer.class);
		setContainerProperty("renderer");
	}

	@Override
	public void doParse(Element element, ParserContext parserContext,
			BeanDefinitionBuilder builder) {
		// Attributes
		String value = element.getAttribute("value");
		// Creates the label info provider
		BeanDefinitionBuilder infoProviderDefinition = BeanDefinitionBuilder
				.rootBeanDefinition(ExpressionLabelInfoProvider.class);
		// Properties
		infoProviderDefinition.addPropertyValue("expression", value);
		// Sets into the contained bean)
		builder.addPropertyValue("labelProvider", infoProviderDefinition
				.getBeanDefinition());
		// OK
		super.doParse(element, parserContext, builder);
	}

}
