package net.sf.doolin.gui.spring.tree;

import net.sf.doolin.context.spring.SimpleDefinitionParser;
import net.sf.doolin.gui.field.table.Column;
import net.sf.doolin.gui.field.tree.Node;
import net.sf.doolin.gui.swing.ExpressionLabelInfoProvider;
import net.sf.doolin.util.xml.DOMUtils;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.support.BeanDefinitionBuilder;
import org.springframework.beans.factory.xml.ParserContext;
import org.w3c.dom.Element;

/**
 * Parser for {@link Column}.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class TreeNodeParser extends SimpleDefinitionParser<Node> {

	/**
	 * Constructor
	 */
	public TreeNodeParser() {
		super(Node.class);
		// Simple properties
		addSimpleAttribute("id");
		addSimpleAttribute("root");
		addSimpleAttribute("changeSupport");
	}

	@Override
	public void doParse(Element element, ParserContext parserContext,
			BeanDefinitionBuilder builder) {
		// Default parsing
		super.doParse(element, parserContext, builder);

		String textExpression = DOMUtils.getAttribute(element,
				"textExpression", false, null);
		String iconExpression = DOMUtils.getAttribute(element,
				"iconExpression", false, null);

		if (StringUtils.isNotBlank(textExpression)
				|| StringUtils.isNotBlank(iconExpression)) {
			// Creates the label info provider
			BeanDefinitionBuilder providerDefinition = BeanDefinitionBuilder
					.rootBeanDefinition(ExpressionLabelInfoProvider.class);
			// Sets the attributes
			if (StringUtils.isNotBlank(textExpression)) {
				providerDefinition.addPropertyValue("expression",
						textExpression);
			}
			if (StringUtils.isNotBlank(iconExpression)) {
				providerDefinition.addPropertyValue("iconExpression",
						iconExpression);
			}
			// Sets into the contained bean
			builder.addPropertyValue("labelProvider", providerDefinition
					.getBeanDefinition());
		}
	}

}
