package net.sf.doolin.gui.swing;

import javax.swing.Icon;

import net.sf.doolin.gui.service.IconService;
import net.sf.doolin.gui.service.IconSize;
import net.sf.doolin.gui.service.icon.DefaultIconService;
import net.sf.doolin.gui.util.GUIStrings;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;

/**
 * This label provider is based on the class name of the item.
 */
public class ClassLabelInfoProvider implements LabelInfoProvider {

	private boolean useFullName = false;

	private IconService iconService = new DefaultIconService();

	/**
	 * Gets the icon service used to access icons
	 * 
	 * @return Icon service
	 */
	public IconService getIconService() {
		return this.iconService;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public LabelInfo getLabelIcon(Object item) {
		// Null
		if (item == null) {
			return new LabelInfo(" ");
		}
		// Class name
		String className = item.getClass().getName();
		if (!this.useFullName) {
			className = StringUtils.substringAfterLast(className, ".");
		}
		// Keys
		String textKey = className;
		String iconKey = textKey + ".icon";
		// Text
		String text = GUIStrings.getIfPresent(textKey);
		// Icon
		Icon icon = null;
		String iconId = GUIStrings.getIfPresent(iconKey);
		if (iconId != null) {
			icon = this.iconService.getIcon(iconId, IconSize.SMALL);
		}
		// OK
		return new LabelInfo(text, icon);
	}

	/**
	 * Checks if is use full name.
	 * 
	 * @return true, if is use full name
	 */
	public boolean isUseFullName() {
		return this.useFullName;
	}

	/**
	 * Sets the icon service used to access icons
	 * 
	 * @param iconService
	 *            Icon service
	 */
	@Autowired(required = false)
	public void setIconService(IconService iconService) {
		this.iconService = iconService;
	}

	/**
	 * Sets the use full name of the enumeration class.
	 * 
	 * @param useFullName
	 *            the new use full name
	 */
	public void setUseFullName(boolean useFullName) {
		this.useFullName = useFullName;
	}
}
