package net.sf.doolin.gui.swing;

import java.io.File;
import java.util.concurrent.atomic.AtomicBoolean;

import javax.swing.JComponent;
import javax.swing.JTextField;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;

/**
 * {@link IFilePath} implementation based on a {@link JTextField}.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class TextFilePath extends AbstractFilePath {

	private final JTextField field;

	/**
	 * Flag for update of the text field
	 */
	private final AtomicBoolean fieldUpdated = new AtomicBoolean(false);

	/**
	 * Constructor.
	 */
	public TextFilePath() {
		this.field = new JTextField(20);

		this.field.getDocument().addDocumentListener(new DocumentListener() {

			@Override
			public void changedUpdate(DocumentEvent e) {
				update();
			}

			@Override
			public void insertUpdate(DocumentEvent e) {
				update();
			}

			@Override
			public void removeUpdate(DocumentEvent e) {
				update();
			}

			private void update() {
				TextFilePath.this.fieldUpdated.set(true);
				try {
					fireNewPath(TextFilePath.this.field.getText());
				} finally {
					TextFilePath.this.fieldUpdated.set(false);
				}
			}
		});
	}

	@Override
	public JComponent getComponent() {
		return this.field;
	}

	@Override
	public String getFilePath() {
		return this.field.getText();
	}

	@Override
	public void setEnabled(boolean enabled) {
		this.field.setEditable(enabled);
	}

	@Override
	public void setFile(File file) {
		if (!this.fieldUpdated.get()) {
			if (file == null) {
				this.field.setText(null);
			} else {
				this.field.setText(file.getAbsolutePath());
			}
		}
	}

}
