package net.sf.doolin.gui.validation;

import java.util.Collections;
import java.util.List;

import net.sf.doolin.bus.support.SubscriberValidator;

/**
 * Chain of validators.
 * 
 * @param <B>
 *            Type of object for the view
 * @author Damien Coraboeuf
 */
public class ChainedValidator<B> extends AbstractValidator<B> {

	private List<GUIValidator<B>> validators = Collections.emptyList();

	/**
	 * Gets the validators.
	 * 
	 * @return the validators
	 */
	public List<GUIValidator<B>> getValidators() {
		return this.validators;
	}

	/**
	 * Sets the validators.
	 * 
	 * @param validators
	 *            the new validators
	 */
	public void setValidators(List<GUIValidator<B>> validators) {
		this.validators = validators;
	}

	@Override
	protected void validate(GUIValidation validationResult, B model) {
		for (GUIValidator<B> validator : this.validators) {
			GUIValidation subResults = validator.validate(model);
			validationResult.addAllFrom(subResults);
		}
	}

	@Override
	public void subscribe(SubscriberValidator subscriberValidator, B model,
			Runnable runnable) {
		for (GUIValidator<B> validator : this.validators) {
			validator.subscribe(subscriberValidator, model, runnable);
		}
	}

}
