package net.sf.doolin.gui.validation;

import javax.swing.JComponent;

import net.sf.doolin.gui.field.Field;
import net.sf.doolin.gui.view.GUIView;
import net.sf.doolin.gui.view.decorator.DecorationStyle;

import org.apache.commons.lang.StringUtils;

/**
 * Default decorator for the validation of the view. It uses an instance of
 * {@link IconFeedbackPanel}.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class DefaultValidationGUIViewDecorator extends
		AbstractValidationGUIViewDecorator {

	@Override
	protected <V> JComponent createValidationComponent(GUIView<V> view,
			JComponent component, DecorationStyle decorationStyle,
			ValidationSupport<V> validationSupport) {
		return new IconFeedbackPanel(validationSupport, component);
	}

	@Override
	public <V> JComponent decorateField(Field<V> field,
			JComponent fieldComponent) {
		// View
		GUIValidator<V> validator = field.getView().getViewDescriptor()
				.getValidator();
		// Enable validation
		if (validator != null) {
			String fieldName = field.getFieldDescriptor().getName();
			if (StringUtils.isNotBlank(fieldName)) {
				ValidationComponentUtils.setMessageKey(fieldComponent,
						fieldName);
			}
		}
		// OK
		return fieldComponent;
	}
}
