package net.sf.doolin.gui.view;

import javax.swing.JComponent;

import net.sf.doolin.gui.action.ActionContext;
import net.sf.doolin.gui.action.path.list.ActionPathList;
import net.sf.doolin.gui.app.GUIApplication;
import net.sf.doolin.gui.util.PropertyContainer;
import net.sf.doolin.gui.view.descriptor.GUIViewDescriptor;
import net.sf.doolin.gui.window.GUIWindow;

/**
 * View instance.
 * 
 * @param <B>
 *            Type of the view data.
 * 
 * @author Damien Coraboeuf
 */
public interface GUIView<B> extends PropertyContainer {

	/**
	 * Adds a listener for the view life-cycle
	 * 
	 * @param listener
	 *            Listener to add
	 */
	void addViewListener(GUIViewListener<B> listener);

	/**
	 * Actually closes the view
	 */
	void close();

	/**
	 * Closes the view
	 * 
	 * @param force
	 *            <code>true</code> if the view <i>must</i> be closed.
	 * @return <code>true</code> if the view could be closed
	 */
	boolean close(boolean force);

	/**
	 * Gets the action context for this view
	 * 
	 * @return Action context
	 */
	ActionContext getActionContext();

	/**
	 * Gets the view owner
	 * 
	 * @return Application
	 */
	GUIApplication getApplication();

	/**
	 * Gets the ID for the view
	 * 
	 * @return ID
	 */
	String getID();

	/**
	 * Gets the parent window.
	 * 
	 * @return the parent window
	 */
	GUIWindow<?> getParentWindow();

	/**
	 * Gets the view component.
	 * 
	 * @return the view component
	 */
	JComponent getViewComponent();

	/**
	 * Data for the view
	 * 
	 * @return Data
	 */
	B getViewData();

	/**
	 * Gets the view descriptor.
	 * 
	 * @return the view descriptor
	 */
	GUIViewDescriptor<B> getViewDescriptor();

	/**
	 * This method when the view is created.
	 */
	void init();

	/**
	 * Installs a tool bar in the view
	 * 
	 * @param toolBar
	 *            Tool bar specification
	 * @param actionContext
	 *            Action context for the tool bar
	 */
	void installToolBar(ActionPathList toolBar, ActionContext actionContext);

	/**
	 * Returns <code>true</code> if the view is closed.
	 * 
	 * @return <code>true</code> if the view is closed.
	 */
	boolean isClosed();

	/**
	 * Removes a listener for the view life-cycle
	 * 
	 * @param listener
	 *            Listener to remove
	 */
	void removeViewListener(GUIViewListener<B> listener);

	/**
	 * Shows the view
	 */
	void show();

}
