package net.sf.doolin.gui.view.support;

import net.sf.doolin.gui.expression.GUIExpression;
import net.sf.doolin.gui.view.GUIView;

/**
 * Utility methods for the views
 * 
 * @author Damien Coraboeuf
 * 
 */
public class GUIViewUtils {

	private GUIViewUtils() {
	}

	/**
	 * Gets the title of the view
	 * 
	 * @param <V>
	 *            Type of object for the view
	 * @param view
	 *            View
	 * @return Title
	 * @see #getTitleExpression(GUIView)
	 * @see GUIExpression#getValue()
	 */
	public static <V> String getTitle(GUIView<V> view) {
		return getTitleExpression(view).getValue();
	}

	/**
	 * Gets the parsed title expression for a view
	 * 
	 * @param <V>
	 *            Type of object for the view
	 * @param view
	 *            View
	 * @return Title expression
	 * @see GUIView#getViewDescriptor()
	 * @see net.sf.doolin.gui.view.descriptor.GUIViewDescriptor#getTitleExpression()
	 */
	public static <V> GUIExpression getTitleExpression(GUIView<V> view) {
		String titleExpression = view.getViewDescriptor().getTitleExpression();
		GUIExpression titleGUIExpression = new GUIExpression(view
				.getActionContext().getSubscriberValidator(), view
				.getViewData(), titleExpression);
		return titleGUIExpression;
	}

}
