package net.sf.doolin.gui.window.descriptor;

import javax.annotation.PostConstruct;
import javax.swing.JComponent;
import javax.swing.JPanel;

import net.sf.doolin.gui.layout.LayoutManagerService;
import net.sf.doolin.gui.layout.LayoutService;
import net.sf.doolin.gui.view.GUIView;
import net.sf.doolin.gui.view.decorator.DefaultGUIViewDecorator;
import net.sf.doolin.gui.window.GUIWindow;

/**
 * Default window descriptor, based on a layout service.
 * 
 * @param <B>
 *            Type of data for the window
 * @author Damien Coraboeuf
 */
public class LayoutGUIWindowDescriptor<B> extends
		AbstractCompositeGUIWindowDescriptor<B, Object> {

	private LayoutService layoutService = new LayoutManagerService();

	/**
	 * Sets a {@linkplain DefaultGUIViewDecorator default view decorator} is
	 * none is
	 * {@linkplain #setViewDecorator(net.sf.doolin.gui.view.decorator.GUIViewDecorator)
	 * set}.
	 */
	@PostConstruct
	public void init() {
		// Sets the default view decorator
		if (getViewDecorator() == null) {
			setViewDecorator(new DefaultGUIViewDecorator());
		}
	}

	@Override
	protected void arrangeWindow(GUIWindow<B> window) {
		// Gets the window content
		JPanel windowPanel = window.getWindowPanel();
		// Sets its layout
		this.layoutService.init(windowPanel);
	}

	@Override
	protected <V> void arrangeViewInWindow(GUIWindow<B> window,
			GUIView<V> view, JComponent viewDecoratedComponent,
			Object constraint) {
		// Gets the window content
		JPanel windowPanel = window.getWindowPanel();
		// Positions the view
		this.layoutService.add(windowPanel, viewDecoratedComponent, constraint);
	}

	/**
	 * Gets the layout service.
	 * 
	 * @return the layout service
	 */
	public LayoutService getLayoutService() {
		return this.layoutService;
	}

	/**
	 * Layout manager to use for positioning the views in the window
	 * 
	 * @param layoutService
	 *            the new layout service
	 */
	public void setLayoutService(LayoutService layoutService) {
		this.layoutService = layoutService;
	}

}
