package net.sf.doolin.gui.window.descriptor;

import java.awt.BorderLayout;

import javax.swing.JComponent;
import javax.swing.JPanel;

import net.sf.doolin.gui.view.GUIView;
import net.sf.doolin.gui.view.decorator.DecorationStyle;
import net.sf.doolin.gui.view.decorator.GUIViewDecorator;
import net.sf.doolin.gui.view.descriptor.GUIViewDescriptor;
import net.sf.doolin.gui.window.GUIWindow;

/**
 * Descriptor for a window that contains only one view.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <B>
 *            Type of data for the window and the view
 */
public class SimpleGUIWindowDescriptor<B> extends
		AbstractGUIWindowDescriptor<B> {

	private GUIViewDescriptor<B> viewDescriptor;
	private GUIViewDecorator viewDecorator;
	private DecorationStyle decorationStyle;

	@Override
	protected void arrangeViews(GUIWindow<B> window) {
		// Creates the view
		GUIView<B> view = this.viewDescriptor.createView(window, window
				.getWindowData());
		// View component
		JComponent viewComponent = initViewComponent(window, view,
				this.viewDecorator, this.decorationStyle);
		// Gets the window content
		JPanel windowPanel = window.getWindowPanel();
		// Positions the view in the window
		windowPanel.add(viewComponent, BorderLayout.CENTER);
		// Registers the view
		view.init();
	}

	@Override
	protected void arrangeWindow(GUIWindow<B> window) {
		// Gets the window content
		JPanel windowPanel = window.getWindowPanel();
		// Sets its layout
		windowPanel.setLayout(new BorderLayout());
	}

	/**
	 * Gets the decoration style for the view decorator
	 * 
	 * @return Decoration style
	 */
	public DecorationStyle getDecorationStyle() {
		return this.decorationStyle;
	}

	/**
	 * Gets the optional decorator to apply to the view in the window
	 * 
	 * @return View decorator
	 */
	public GUIViewDecorator getViewDecorator() {
		return this.viewDecorator;
	}

	/**
	 * Gets the descriptor of the view to include in this window
	 * 
	 * @return View descriptor
	 */
	public GUIViewDescriptor<B> getViewDescriptor() {
		return this.viewDescriptor;
	}

	/**
	 * Does nothing and just returns <code>null</code>.
	 */
	@Override
	public <V> GUIView<V> openView(GUIWindow<B> parentWindow,
			GUIViewDescriptor<V> viewDescriptor, V viewData) {
		return null;
	}

	/**
	 * Sets the decoration style for the view decorator
	 * 
	 * @param decorationStyle
	 *            Decoration style
	 */
	public void setDecorationStyle(DecorationStyle decorationStyle) {
		this.decorationStyle = decorationStyle;
	}

	/**
	 * Sets the optional decorator to apply to the view in the window
	 * 
	 * @param viewDecorator
	 *            View decorator
	 */
	public void setViewDecorator(GUIViewDecorator viewDecorator) {
		this.viewDecorator = viewDecorator;
	}

	/**
	 * Sets the descriptor of the view to include in this window
	 * 
	 * @param viewDescriptor
	 *            View descriptor
	 */
	public void setViewDescriptor(GUIViewDescriptor<B> viewDescriptor) {
		this.viewDescriptor = viewDescriptor;
	}

}
