package net.sf.doolin.gui.window.descriptor;

import net.sf.doolin.gui.view.decorator.DecorationStyle;
import net.sf.doolin.gui.view.descriptor.GUIViewDescriptor;
import net.sf.doolin.util.factory.DataFactory;
import net.sf.doolin.util.factory.IdentityDataFactory;

import org.springframework.beans.factory.annotation.Required;

/**
 * Description of a view in a window.
 * 
 * @author Damien Coraboeuf
 * @param <V>
 *            Type of data for the view
 * @param <C>
 *            Type of constraint for the views
 */
public class ViewReference<V, C> {

	private boolean visible = true;

	private GUIViewDescriptor<V> viewDescriptor;

	private DataFactory<V> modelFactory = new IdentityDataFactory<V>();

	private C viewConstraint;

	private DecorationStyle decorationStyle;

	/**
	 * Gets the decoration style.
	 * 
	 * @return the decoration style
	 */
	public DecorationStyle getDecorationStyle() {
		return this.decorationStyle;
	}

	/**
	 * Describes the way to get the model for the sub-view from the parent model
	 * 
	 * @return the model factory
	 */
	public DataFactory<V> getModelFactory() {
		return this.modelFactory;
	}

	/**
	 * Gets the view constraint.
	 * 
	 * @return the view constraint
	 */
	public C getViewConstraint() {
		return this.viewConstraint;
	}

	/**
	 * Gets the view descriptor.
	 * 
	 * @return the view descriptor
	 */
	public GUIViewDescriptor<V> getViewDescriptor() {
		return this.viewDescriptor;
	}

	/**
	 * Checks if is visible.
	 * 
	 * @return true, if is visible
	 */
	public boolean isVisible() {
		return this.visible;
	}

	/**
	 * Sets the decoration style.
	 * 
	 * @param decorationStyle
	 *            the new decoration style
	 */
	public void setDecorationStyle(DecorationStyle decorationStyle) {
		this.decorationStyle = decorationStyle;
	}

	/**
	 * Sets the model factory.
	 * 
	 * @param modelFactory
	 *            the new model factory
	 */
	public void setModelFactory(DataFactory<V> modelFactory) {
		this.modelFactory = modelFactory;
	}

	/**
	 * View constraint for the positionning
	 * 
	 * @param viewConstraint
	 *            the new view constraint
	 */
	public void setViewConstraint(C viewConstraint) {
		this.viewConstraint = viewConstraint;
	}

	/**
	 * Sets the view descriptor.
	 * 
	 * @param viewDescriptor
	 *            the new view descriptor
	 */
	@Required
	public void setViewDescriptor(GUIViewDescriptor<V> viewDescriptor) {
		this.viewDescriptor = viewDescriptor;
	}

	/**
	 * Initial visibility of the view
	 * 
	 * @param visible
	 *            the new visible
	 */
	public void setVisible(boolean visible) {
		this.visible = visible;
	}

	@Override
	public String toString() {
		return String.format("%s@%s", this.viewDescriptor.getViewId(),
				this.viewConstraint);
	}

}
