package net.sf.doolin.gui.window.dialog;

import javax.swing.UIManager;

import net.sf.doolin.gui.action.ActionContext;

/**
 * Standard Cancel action for a dialog
 * 
 * @author Damien Coraboeuf (x74639)
 * 
 * @param <B>
 *            Type of data for the dialog
 */
public class DialogCancelAction<B> extends AbstractDialogAction<B> {

	/**
	 * Constructor
	 * 
	 * @see DialogAction#CANCEL
	 */
	public DialogCancelAction() {
		super(DialogAction.CANCEL, UIManager
				.getString("OptionPane.cancelButtonText"), false);
	}

	/**
	 * Invalidates the model and cancels the dialog
	 */
	@Override
	protected void doExecute(ActionContext context) throws Exception {
		// Invalidates the model
		context.getValidationSupport().invalidate();
		// Cancels the dialog
		getDialog(context).close();
	}

	/**
	 * Shortcut
	 */
	@Override
	protected String getShortcut() {
		return "ESCAPE";
	}

}
