package net.sf.doolin.gui.window.support;

import java.awt.Container;
import java.awt.event.WindowListener;

import javax.swing.Icon;
import javax.swing.JButton;
import javax.swing.JRootPane;

/**
 * This interface is a wrapper around either a {@link javax.swing.JFrame} or a
 * {@link javax.swing.JDialog}.
 * 
 * @author Damien Coraboeuf
 * 
 */
public interface IWindow {

	/**
	 * Adds a window listener
	 * 
	 * @param windowListener
	 */
	void addWindowListener(WindowListener windowListener);

	/**
	 * Disposes of the window.
	 */
	void dispose();

	/**
	 * Gets the content pane of the window
	 * 
	 * @return Content pane
	 */
	Container getContentPane();

	int getHeight();

	/**
	 * Gets the root pane of the underlying window.
	 * 
	 * @return The root pane of the create window
	 * @deprecated Uses direct accessors like {@link #setDefaultButton(JButton)}
	 */
	@Deprecated
	JRootPane getRootPane();

	int getWidth();

	/**
	 * Returns <code>true</code> if the underlying implementation is modal (like
	 * if using a {@link javax.swing.JDialog}).
	 * 
	 * @return <code>true</code> if the window is modal
	 */
	boolean isModal();

	void pack();

	void setDefaultButton(JButton button);

	/**
	 * Sets the window icon
	 * 
	 * @param icon
	 *            Icon to set
	 */
	void setIcon(Icon icon);

	/**
	 * Sets the location of the window according to its parent
	 */
	void setLocation();

	/**
	 * Sets the size of the window
	 * 
	 * @param width
	 *            Width in pixels
	 * @param height
	 *            Height in pixels
	 */
	void setSize(int width, int height);

	/**
	 * Sets the title of the window
	 * 
	 * @param value
	 *            Title to set
	 */
	void setTitle(String value);

	/**
	 * Shows the window
	 */
	void show();

}
