package net.sf.doolin.gui.window.support;

/**
 * Window size specification.
 */
public class WindowSize {

	private int width = 400;

	private int height = 400;

	private boolean saveInPrefs = false;

	private boolean pack = false;

	private boolean maximized = false;

	private boolean centered = false;

	/**
	 * Gets the height.
	 * 
	 * @return the height
	 */
	public int getHeight() {
		return this.height;
	}

	/**
	 * Gets the width.
	 * 
	 * @return the width
	 */
	public int getWidth() {
		return this.width;
	}

	/**
	 * Checks if the window must be centred on the screen
	 * 
	 * @return <code>true</code> if the window must be centred on the screen
	 */
	public boolean isCentered() {
		return this.centered;
	}

	/**
	 * Checks if is maximized.
	 * 
	 * @return true, if is maximized
	 */
	public boolean isMaximized() {
		return this.maximized;
	}

	/**
	 * Checks if is pack.
	 * 
	 * @return true, if is pack
	 */
	public boolean isPack() {
		return this.pack;
	}

	/**
	 * Checks if is save in prefs.
	 * 
	 * @return true, if is save in prefs
	 */
	public boolean isSaveInPrefs() {
		return this.saveInPrefs;
	}

	/**
	 * Sets if the window must be centred on the screen
	 * 
	 * @param centered
	 *            <code>true</code> if the window must be centred on the screen
	 */
	public void setCentered(boolean centered) {
		this.centered = centered;
	}

	/**
	 * Sets the height.
	 * 
	 * @param height
	 *            the new height
	 */
	public void setHeight(int height) {
		this.height = height;
	}

	/**
	 * Sets the maximized.
	 * 
	 * @param maximized
	 *            the new maximized
	 */
	public void setMaximized(boolean maximized) {
		this.maximized = maximized;
	}

	/**
	 * Sets the pack.
	 * 
	 * @param pack
	 *            the new pack
	 */
	public void setPack(boolean pack) {
		this.pack = pack;
	}

	/**
	 * Sets the save in prefs.
	 * 
	 * @param saveInPrefs
	 *            the new save in prefs
	 */
	public void setSaveInPrefs(boolean saveInPrefs) {
		this.saveInPrefs = saveInPrefs;
	}

	/**
	 * Sets the width.
	 * 
	 * @param width
	 *            the new width
	 */
	public void setWidth(int width) {
		this.width = width;
	}

}
